@@ -7,9 +7,7 @@ use File::Basename;
 use Cwd;
 use IO::File;
 use utf8;
-use Encode;
 use Encode::Guess;
-use Carp;
 #use Data::Dumper;
 
 use HTML::Parser 3.40;
@@ -19,7 +17,7 @@ use base qw(HTML::Parser);
 
 #use Data::Dumper;
 
-our $VERSION = '1.1.1';
+our $VERSION = '1.1';
 
 =head1 NAME
 
@@ -106,13 +104,11 @@ sub parse_to {
 	$self->set_destination($destination_path);
 	$self->io_layer();
 	
-	my $output = '';
-	my $fh = IO::File->new(\$output, ">:utf8");
-	$self->{'outputHTML'} = $fh;
+	my $outHandle = dummyIO->new();
+	$self->{'outputHTML'} = $outHandle;
 	$self->SUPER::parse($self->{'SourceHTML'});
 	$self->eof;
-	$fh->close;
-	return decode_utf8($output);
+	return join('',@{$outHandle->{'output'}});
 }
 
 =head1 Class Methods
@@ -343,4 +339,22 @@ sub output{
 	$self->{'outputHTML'}->print($out_text);
 }
 
+##== obsolute
+
+package dummyIO;
+
+use strict;
+use warnings;
+
+sub new {
+  my $class = shift @_;
+  my $self = bless {'output'=>[]}, $class;
+  return $self;
+}
+
+sub print {
+  my ($self,$outText) = @_;
+  push(@{$self -> {'output'}}, $outText);
+}
+
 1;
